==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/inputs/GetSqlDWTableDataSetMappingPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.inputs

import com.pulumi.azurenative.datashare.inputs.GetSqlDWTableDataSetMappingPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the share account.
 * @property dataSetMappingName The name of the dataSetMapping.
 * @property resourceGroupName The resource group name.
 * @property shareSubscriptionName The name of the shareSubscription.
 */
public data class GetSqlDWTableDataSetMappingPlainArgs(
    public val accountName: String,
    public val dataSetMappingName: String,
    public val resourceGroupName: String,
    public val shareSubscriptionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datashare.inputs.GetSqlDWTableDataSetMappingPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.datashare.inputs.GetSqlDWTableDataSetMappingPlainArgs =
        com.pulumi.azurenative.datashare.inputs.GetSqlDWTableDataSetMappingPlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .dataSetMappingName(dataSetMappingName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .shareSubscriptionName(shareSubscriptionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlDWTableDataSetMappingPlainArgs].
 */
@PulumiTagMarker
public class GetSqlDWTableDataSetMappingPlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var dataSetMappingName: String? = null

    private var resourceGroupName: String? = null

    private var shareSubscriptionName: String? = null

    /**
     * @param value The name of the share account.
     */
    @JvmName("exojokkikqudfyxw")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the dataSetMapping.
     */
    @JvmName("hpqfqoytioxxdbjq")
    public suspend fun dataSetMappingName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.dataSetMappingName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("kfsisvgbubpobbqc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the shareSubscription.
     */
    @JvmName("cudjjoseulvtiqpa")
    public suspend fun shareSubscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.shareSubscriptionName = mapped
    }

    internal fun build(): GetSqlDWTableDataSetMappingPlainArgs = GetSqlDWTableDataSetMappingPlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        dataSetMappingName = dataSetMappingName ?: throw PulumiNullFieldException("dataSetMappingName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        shareSubscriptionName = shareSubscriptionName ?: throw
            PulumiNullFieldException("shareSubscriptionName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/inputs/GetSqlDWTableDataSetMappingPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.inputs

import com.pulumi.azurenative.datashare.inputs.GetSqlDWTableDataSetMappingPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the share account.
 * @property dataSetMappingName The name of the dataSetMapping.
 * @property resourceGroupName The resource group name.
 * @property shareSubscriptionName The name of the shareSubscription.
 */
public data class GetSqlDWTableDataSetMappingPlainArgs(
    public val accountName: String,
    public val dataSetMappingName: String,
    public val resourceGroupName: String,
    public val shareSubscriptionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datashare.inputs.GetSqlDWTableDataSetMappingPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.datashare.inputs.GetSqlDWTableDataSetMappingPlainArgs =
        com.pulumi.azurenative.datashare.inputs.GetSqlDWTableDataSetMappingPlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .dataSetMappingName(dataSetMappingName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .shareSubscriptionName(shareSubscriptionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlDWTableDataSetMappingPlainArgs].
 */
@PulumiTagMarker
public class GetSqlDWTableDataSetMappingPlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var dataSetMappingName: String? = null

    private var resourceGroupName: String? = null

    private var shareSubscriptionName: String? = null

    /**
     * @param value The name of the share account.
     */
    @JvmName("ohjalpbynwvbsumg")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the dataSetMapping.
     */
    @JvmName("fifrabxbpapltycc")
    public suspend fun dataSetMappingName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.dataSetMappingName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("dbogmpesfefxgccp")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the shareSubscription.
     */
    @JvmName("jkyomafdielggppe")
    public suspend fun shareSubscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.shareSubscriptionName = mapped
    }

    internal fun build(): GetSqlDWTableDataSetMappingPlainArgs = GetSqlDWTableDataSetMappingPlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        dataSetMappingName = dataSetMappingName ?: throw PulumiNullFieldException("dataSetMappingName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        shareSubscriptionName = shareSubscriptionName ?: throw
            PulumiNullFieldException("shareSubscriptionName"),
    )
}
